GOOF----LE-4-2.0      ] 4       h      ] g  guile	 	g  define-module*	 	 	g  web	g  client	 		g  filenameS	
f  web/client.scm	g  importsS	g  rnrs	
g  bytevectors	
 	 	g  ice-9	g  binary-ports	 	 	g  iconv	 	 	g  rdelim	 	 	g  request	 	 	g  response	 	 	 g  uri	!  	"! 	#g  http	$# 	%$ 	&g  srfi	'g  srfi-1	(&' 	)( 	*g  srfi-9	+&* 	,+ 	-g  gnu	.&*- 	/. 	0"%),/ 	1g  exportsS	2g  current-http-proxy	3g  open-socket-for-uri	4g  http-get	5g  	http-get*	6g  	http-head	7g  	http-post	8g  http-put	9g  http-delete	:g  
http-trace	;g  http-options	<23456789:; 
	=g  set-current-module	>= 	?= 	@g  make-parameter	Ag  getenv	Bf  
http_proxy	Cf   	Dg  string?	Eg  string->uri	Fg  error	Gf  Invalid URI	Hg  <uri>	I!H 	J!H 	Kg  
ensure-uri	Lg  throw-bad-struct	M+L 	N+L 	Og  uri-port	Pg  delete-duplicates	Qg  getaddrinfo	Rg  uri-host	Sg  number->string	Tg  symbol->string	Ug  
uri-scheme	Vg  AI_NUMERICSERV	Wg  
addrinfo:addr	Xg  %default-port-encoding	Yg  socket	Zg  addrinfo:fam	[g  SOCK_STREAM	\g  
IPPROTO_IP	]g  catch	^g  system-error	_g  connect	`g  setvbuf	ag  _IOFBF	bg  
setsockopt	cg  
SOL_SOCKET	dg  	SO_RCVBUF	eg  set-http-proxy-port?!	fg  close	gg  throw	hg  	<request>	ih 	jh 	kg  
assoc-set!	lg  	copy-tree	mg  %%<request>-set-fields	ng  extend-request	og  request-content-type	pg  
text/plain	qp 	rg  assq-ref	sg  charset	tg  sanitize-request	ug  content-type	vg  append	wv 	xv 	yf  utf-8	zg  string->bytevector	{g  
procedure?	|g  call-with-encoded-output-string	}g  bytevector?	~g  request-content-length	g  bytevector-length f  bad content-length g  content-length f  unexpected body type f  content-length, but no body g  assq g  transfer-encoding g  request-headers f  *transfer-encoding not allowed with no body g  vu8
	  j    g  response-content-length g  response-content-type g  text-content-type? g  bytevector->string f  
iso-8859-1 g  decode-response-body g  bodyS  g  portS 	 g  methodS 	 g  versionS 	 g  keep-alive?S 	 g  headersS 	 g  decode-body?S 	 g  
streaming?S 	 g  requestS 		  	 g  GET  g  
build-request g  
connection f  g  
write-request g  write-request-body g  force-output g  request-port g  
read-response g  request-method g  HEAD g  
close-port g  response-body-port g  decode?S g  read-response-body 	 	 g  
extra-headersS 	   g  issue-deprecation-warning f  HThe #:extra-headers argument to http-get has been renamed to #:headers.  f  Please update your code.   f  "`http-get*' has been deprecated.   f  BInstead, use `http-get' with the #:streaming? #t keyword argument. g  make-syntax-transformer     g  define-http-verb g  macro g  $sc-dispatch     g  any   g  
syntax-object g  define* g  top   g  ribcage g  dummy g  	http-verb g  method g  doc   g  m-CCSxwggPgrtKFRq9kkHjhx-5361     f  l-CCSxwggPgrtKFRq9kkHjhx-5366 f  l-CCSxwggPgrtKFRq9kkHjhx-5367 f  l-CCSxwggPgrtKFRq9kkHjhx-5368 f  l-CCSxwggPgrtKFRq9kkHjhx-5369       g  x     f  l-CCSxwggPgrtKFRq9kkHjhx-5363       g  hygiene        g  keyS   g  body       g  port   3      g  version   g  quote          g  keep-alive?     g  headers       g  decode-body?    g  
streaming?   	 	 
   
    
 g  syntax-violation  f  -source expression failed to match any pattern			 g  POSTg  PUTg  DELETEg  TRACEg  OPTIONSC 5 ho  -  ]4	
01<5 4? >  "  G   4@i4AiB5  C$  "    52RDEFGJ      h@      ]4 5$   6"   6 $   &   C""             g  
uri-or-string
		:  g  filenamef  web/client.scm
	=
		?		
	>			?			A			A				>		"	@		&	>		)	@	 		:  g  nameg  
ensure-uri CKR2KJNOPQRSTUVW   h   |   ]4 545C      t       g  ai1
		 g  ai2		  g  filenamef  web/client.scm
	P			Q		
	Q	%		Q		 			   CXYZ[\]^_W`abcde 	hh      ] 4L4L5>  "  G  4L>  "  G  4L0 >  "  G  M $  4L>  "  G  "   LC       g  filenamef  web/client.scm
	Y			Z	
		Z			Z	
		]	
	0	_	
	;	_	-	@	_	
	N	a	
	O	a	 		h
   Cfg       h0      -  1  3 4L>  "  G  L (   @LL 6 ~       g  args
			/  g  filenamef  web/client.scm
	c		
	e	
		f		"	f	
	(	g		-	h		/	h	 			/


   C 
      h@      ] Y4455ZLO 	 L O 6            g  	addresses
		; g  ai		; g  s			;  g  filenamef  web/client.scm
	S			T			T		
	W			W			W			T		#	X	
	;	X	 
		;  g  nameg  loop C     h     ]!HHH45 K4J$  J"   5KJ&  	J	"  	4J544J&  	J	"  	4J5$  4	5"  4
J&  J
"  	4J55$  "  
5
5KO Q J6           g  
uri-or-string
	  g  
http-proxy	  g  uri		  g  	addresses		  g  port		B  g  loop	    g  filenamef  web/client.scm
	C
		E			F			F		%	F		*	H		B	H		E	I		H	J		M	J		k	K		w	L	 	|	L	0 	L	  	M	 	J	 	I	 	S	 	   g  nameg  open-socket-for-urig  
documentationf  9Return an open input/output port for a connection to URI. C3RjklNmn  hh     - 1 3  &  3 
  	44 	55 	 	 "  	4 5(  C@              g  r
			a g  k			a g  v				a g  
additional				a g  r		N	a  g  filenamef  web/client.scm
	j
		k		"	l		%	l	"	,	l	-	.	l	"	4	l		9	k		N	k		V	n		a	p	 			a	
	  g  nameg  extend-request CnRDoqrstnuxyz{|}~FjN      h    ]$ 45$  T4 545$   "  4 4	
 554$  "  
5645$  T4 545$   "  4 4	
 554
$  "  
5645$  K4 545$  $   "  45"  4 5D64 5$  "
$  "  4>  "  G  "  <4 &  	 	"  	4 55$  4>  "  G  "    D   }      g  request
	 g  body	 g  type			g g  declared-charset		(	g g  type		{  g  declared-charset	   g  rlen	  g  blen	  g  length	)  	g  filenamef  web/client.scm
	s
	 			 		 		 		 	/	 		 		 		$ 	'	& 	2	( 		( 		2 		9 		? 	#	@ 		H 	)	I 		P 		Q 		[ 		c 	)	e 		g 		h 		r 		s 		y 	(	{ 		{ 		~ 	  	'  	2  	  	  	  	  	#  	  	)  	  	  	  	  	)  	  	  		  	  	  	  	  	  	  	  	  	  	 	 	- 	 	  	" 	# 	) 	1 	4 	9 	
> 	B 	G 	T 	X 	[ 	)u 	y 	
z 	~ 	 	 	 	 T		  g  nameg  sanitize-requestg  
documentation k 0"   S   a   n   i   t   i   z   e   "       t   h   e       g   i   v   e   n       r   e   q   u   e   s   t       a   n   d       b   o   d   y   ,       e   n   s   u   r   i   n   g       t   h   a   t       t   h   e   y       a   r   e   
   c   o   m   p   l   e   t   e       a   n   d       c   o   h   e   r   e   n   t   .           T   h   i   s       m   e   t   h   o   d       i   s       m   o   s   t       u   s   e   f   u   l       f   o   r       m   e   t   h   o   d   s       t   h   a   t       s   e   n   d   
   d   a   t   a       t   o       t   h   e       s   e   r   v   e   r   ,       l   i   k   e       P   O   S   T   ,       b   u   t       c   a   n       b   e       u   s   e   d       f   o   r       a   n   y       m   e   t   h   o   d   .           R   e   t   u   r   n   
   t   w   o       v   a   l   u   e   s   :       a       r   e   q   u   e   s   t       a   n   d       a       b   y   t   e   v   e   c   t   o   r   ,       p   o   s   s   i   b   l   y       t   h   e       s   a   m   e       o   n   e   s       t   h   a   t       w   e   r   e   
   p   a   s   s   e   d       a   s       a   r   g   u   m   e   n   t   s   .   
   
   I   f       B   O   D   Y       i   s       a       s   t   r   i   n   g   ,       e   n   c   o   d   e   s       t   h   e       s   t   r   i   n   g       t   o       a       b   y   t   e   v   e   c   t   o   r   ,       i   n       a   n       e   n   c   o   d   i   n   g   
   a   p   p   r   o   p   r   i   a   t   e       f   o   r       R   E   Q   U   E   S   T   .           A   d   d   s       a          c   o   n   t   e   n   t   -   l   e   n   g   t   h          a   n   d          c   o   n   t   e   n   t   -   t   y   p   e      
   h   e   a   d   e   r   ,       a   s       n   e   c   e   s   s   a   r   y   .   
   
   I   f       B   O   D   Y       i   s       a       p   r   o   c   e   d   u   r   e   ,       i   t       i   s       c   a   l   l   e   d       w   i   t   h       a       p   o   r   t       a   s       a   n       a   r   g   u   m   e   n   t   ,       a   n   d       t   h   e   
   o   u   t   p   u   t       c   o   l   l   e   c   t   e   d       a   s       a       b   y   t   e   v   e   c   t   o   r   .           I   n       t   h   e       f   u   t   u   r   e       w   e       m   i   g   h   t       t   r   y       t   o       i   n   s   t   e   a   d   
   u   s   e       a       c   o   m   p   r   e   s   s   i   n   g   ,       c   h   u   n   k   -   e   n   c   o   d   e   d       p   o   r   t   ,       a   n   d       c   a   l   l       t   h   i   s       p   r   o   c   e   d   u   r   e       l   a   t   e   r   .   
   A   u   t   h   o   r   s       a   r   e       a   d   v   i   s   e   d       n   o   t       t   o       r   e   l   y       o   n       t   h   e       p   r   o   c   e   d   u   r   e       b   e   i   n   g       c   a   l   l   e   d       a   t       a   n   y   
   p   a   r   t   i   c   u   l   a   r       t   i   m   e   .   
   
   N   o   t   e       t   h   a   t       w   e       r   e   l   y       o   n       t   h   e       r   e   q   u   e   s   t       i   t   s   e   l   f       a   l   r   e   a   d   y       h   a   v   i   n   g       b   e   e   n       v   a   l   i   d   a   t   e   d   ,   
   a   s       i   s       t   h   e       c   a   s   e       b   y       d   e   f   a   u   l   t       w   i   t   h       a       r   e   q   u   e   s   t       r   e   t   u   r   n   e   d       b   y       `   b   u   i   l   d   -   r   e   q   u   e   s   t   '   .    CtR}rsF 
   h     ]"$  45$  {4 545"  D4 5$  245$  #45$  "  	6CC$  $  "
6"
6C             g  response
	  g  body	  g  rlen		!  g  blen		!  g  t		0	m g  t		R	e  g  filenamef  web/client.scm
 
	 			 		 		 		 		! 		* 		0 		9 		> 	#	@ 		D 	
	I 	,	N 	6	P 	A	R 	,	R 	(	b 	,	g 		m 		x 		| 	  	  	  	  	 	 	  g  nameg  decode-response-body CR3KtjN   h    - /   
0  
 3 #  #  	4 5#  #  #  #  #  #  	#  -44 5	$  "  
5		4	>  G 
4

5$  4>  "  G  "   4&  		"  	45>  "  G  45
&  
"  	45&  !$  "  4>  "  G  
D$  
4
5D4
5$  "  4>  "  G  
$  
4
5"  D       g  uri
	 g  body	 g  port		 g  method		 g  version		 g  keep-alive?		 g  headers		 g  decode-body?		 g  
streaming?		 g  request			 g  request	
  g  body	  g  request	  g  response	
 g  body	h  g  filenamef  web/client.scm
 
	# 		3 		= 		O 		j 		m 	  	  	(  	"  	  	  	  	  	  	  	
  	  	  	  	 	
 	# 	*' 	
- 	2 	H 	N 	
Q 	a 	b 	h 	p 	u 	 	 	 	 '	
g  bodySg  portS	g  methodS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
streaming?S	g  requestS		 
  g  nameg  request CR3   h   )  - /   	0  	 3 	#  #  	4 5#  #  #  #  $  "  #  #  $  4>  "  G  "    	

6      !      g  uri
	  g  body	  g  port		  g  version		  g  keep-alive?		  g  
extra-headers		  g  headers		  g  decode-body?		  g  
streaming?		   	g  filenamef  web/client.scm
 
	# 		3 		S 	/	Z 	A	t		u		y		{	 	 	 	 
	 
g  bodySg  portS	g  versionS	g  keep-alive?S	g  
extra-headersS	g  headersS	g  decode-body?S	g  
streaming?S	 	  g  nameg  http-getg  
documentation   k C   o   n   n   e   c   t       t   o       t   h   e       s   e   r   v   e   r       c   o   r   r   e   s   p   o   n   d   i   n   g       t   o       U   R   I       a   n   d       a   s   k       f   o   r       t   h   e   
   r   e   s   o   u   r   c   e   ,       u   s   i   n   g       t   h   e          G   E   T          m   e   t   h   o   d   .           I   f       y   o   u       a   l   r   e   a   d   y       h   a   v   e       a       p   o   r   t       o   p   e   n   ,   
   p   a   s   s       i   t       a   s       P   O   R   T   .           T   h   e       p   o   r   t       w   i   l   l       b   e       c   l   o   s   e   d       a   t       t   h   e       e   n   d       o   f       t   h   e   
   r   e   q   u   e   s   t       u   n   l   e   s   s       K   E   E   P   -   A   L   I   V   E   ?       i   s       t   r   u   e   .           A   n   y       e   x   t   r   a       h   e   a   d   e   r   s       i   n       t   h   e   
   a   l   i   s   t       H   E   A   D   E   R   S       w   i   l   l       b   e       a   d   d   e   d       t   o       t   h   e       r   e   q   u   e   s   t   .   
   
   I   f       B   O   D   Y       i   s       n   o   t          #   f      ,       a       m   e   s   s   a   g   e       b   o   d   y       w   i   l   l       a   l   s   o       b   e       s   e   n   t       w   i   t   h       t   h   e       H   T   T   P   
   r   e   q   u   e   s   t   .           I   f       B   O   D   Y       i   s       a       s   t   r   i   n   g   ,       i   t       i   s       e   n   c   o   d   e   d       a   c   c   o   r   d   i   n   g       t   o       t   h   e   
   c   o   n   t   e   n   t   -   t   y   p   e       i   n       H   E   A   D   E   R   S   ,       d   e   f   a   u   l   t   i   n   g       t   o       U   T   F   -   8   .           O   t   h   e   r   w   i   s   e       B   O   D   Y       s   h   o   u   l   d       b   e   
   a       b   y   t   e   v   e   c   t   o   r   ,       o   r          #   f          f   o   r       n   o       b   o   d   y   .           A   l   t   h   o   u   g   h       i   t   '   s       a   l   l   o   w   e   d       t   o       s   e   n   d       a   
   m   e   s   s   a   g   e       b   o   d   y       a   l   o   n   g       w   i   t   h       a   n   y       r   e   q   u   e   s   t   ,       u   s   u   a   l   l   y       o   n   l   y       P   O   S   T       a   n   d       P   U   T       r   e   q   u   e   s   t   s   
   h   a   v   e       b   o   d   i   e   s   .           S   e   e          h   t   t   p   -   p   u   t          a   n   d          h   t   t   p   -   p   o   s   t          d   o   c   u   m   e   n   t   a   t   i   o   n   ,       f   o   r       m   o   r   e   .   
   
   I   f       D   E   C   O   D   E   -   B   O   D   Y   ?       i   s       t   r   u   e   ,       a   s       i   s       t   h   e       d   e   f   a   u   l   t   ,       t   h   e       b   o   d   y       o   f       t   h   e   
   r   e   s   p   o   n   s   e       w   i   l   l       b   e       d   e   c   o   d   e   d       t   o       s   t   r   i   n   g   ,       i   f       i   t       i   s       a       t   e   x   t   u   a   l       c   o   n   t   e   n   t   -   t   y   p   e   .   
   O   t   h   e   r   w   i   s   e       i   t       w   i   l   l       b   e       r   e   t   u   r   n   e   d       a   s       a       b   y   t   e   v   e   c   t   o   r   .   
   
   H   o   w   e   v   e   r   ,       i   f       S   T   R   E   A   M   I   N   G   ?       i   s       t   r   u   e   ,       i   n   s   t   e   a   d       o   f       e   a   g   e   r   l   y       r   e   a   d   i   n   g       t   h   e       r   e   s   p   o   n   s   e   
   b   o   d   y       f   r   o   m       t   h   e       s   e   r   v   e   r   ,       t   h   i   s       f   u   n   c   t   i   o   n       o   n   l   y       r   e   a   d   s       o   f   f       t   h   e       h   e   a   d   e   r   s   .           T   h   e   
   r   e   s   p   o   n   s   e       b   o   d   y       w   i   l   l       b   e       r   e   t   u   r   n   e   d       a   s       a       p   o   r   t       o   n       w   h   i   c   h       t   h   e       d   a   t   a       m   a   y       b   e       r   e   a   d   .   
   U   n   l   e   s   s       K   E   E   P   -   A   L   I   V   E   ?       i   s       t   r   u   e   ,       t   h   e       p   o   r   t       w   i   l   l       b   e       c   l   o   s   e   d       a   f   t   e   r       t   h   e       f   u   l   l   
   r   e   s   p   o   n   s   e       b   o   d   y       h   a   s       b   e   e   n       r   e   a   d   .   
   
   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   p   o   n   s   e       r   e   a   d       f   r   o   m       t   h   e       s   e   r   v   e   r   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e   
   b   o   d   y       a   s       a       s   t   r   i   n   g   ,       b   y   t   e   v   e   c   t   o   r   ,       #   f       v   a   l   u   e   ,       o   r       a   s       a       p   o   r   t       (   i   f       S   T   R   E   A   M   I   N   G   ?       i   s   
   t   r   u   e   )   .    C4R34    h     - /   0   3 #  #  	4 5#  #  #  #  $  "  #  4>  "  G   	

6             g  uri
	  g  body	  g  port		  g  version		  g  keep-alive?		  g  
extra-headers		  g  headers		  g  decode-body?		   g  filenamef  web/client.scm
#
	#%		3&		S(	0	Z(	B	f+		j,		l-		q+	 .	 	 
g  bodySg  portS	g  versionS	g  keep-alive?S	g  
extra-headersS	g  headersS	g  decode-body?S	   g  nameg  	http-get*g  
documentationf  2Deprecated in favor of (http-get #:streaming? #t). C5R4	
 	 h(   i   ] C     a       g  dummy
		# g  	http-verb		# g  method			# g  doc			#  		#	   C      h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  web/client.scm
2
 		"  g  
macro-typeg  syntax-rulesg  patternsg  	http-verbg  methodg  doc   C5R3    h     - /   0   3 #  #  	4 5#  #  #  #  #   	

6       g  uri
		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
streaming?			  g  filenamef  web/client.scm
B
	eC		B
 		
g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
streaming?S	   g  nameg  	http-headg  
documentation k @F   e   t   c   h       m   e   s   s   a   g   e       h   e   a   d   e   r   s       f   o   r       t   h   e       g   i   v   e   n       U   R   I       u   s   i   n   g       t   h   e       H   T   T   P       "   H   E   A   D   "   
   m   e   t   h   o   d   .   
   
   T   h   i   s       f   u   n   c   t   i   o   n       i   s       s   i   m   i   l   a   r       t   o          h   t   t   p   -   g   e   t      ,       e   x   c   e   p   t       i   t       u   s   e   s       t   h   e       "   H   E   A   D   "   
   m   e   t   h   o   d   .           S   e   e          h   t   t   p   -   g   e   t          f   o   r       f   u   l   l       d   o   c   u   m   e   n   t   a   t   i   o   n       o   n       t   h   e       v   a   r   i   o   u   s       k   e   y   w   o   r   d   
   a   r   g   u   m   e   n   t   s       t   h   a   t       a   r   e       a   c   c   e   p   t   e   d       b   y       t   h   i   s       f   u   n   c   t   i   o   n   .   
   
   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d          #   f      .           R   e   s   p   o   n   s   e   s       t   o       H   E   A   D   
   r   e   q   u   e   s   t   s       d   o       n   o   t       h   a   v   e       a       b   o   d   y   .           T   h   e       s   e   c   o   n   d       v   a   l   u   e       i   s       o   n   l   y       r   e   t   u   r   n   e   d       s   o       t   h   a   t   
   o   t   h   e   r       p   r   o   c   e   d   u   r   e   s       c   a   n       t   r   e   a   t       a   l   l       o   f       t   h   e       h   t   t   p   -   f   o   o       v   e   r   b   s       i   d   e   n   t   i   c   a   l   l   y   .    C6R3        h   i  - /   0   3 #  #  	4 5#  #  #  #  #   	

6 a      g  uri
		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
streaming?			  g  filenamef  web/client.scm
O
	eP		O
 		
g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
streaming?S	   g  nameg  	http-postg  
documentation k P   o   s   t       d   a   t   a       t   o       t   h   e       g   i   v   e   n       U   R   I       u   s   i   n   g       t   h   e       H   T   T   P       "   P   O   S   T   "       m   e   t   h   o   d   .   
   
   T   h   i   s       f   u   n   c   t   i   o   n       i   s       s   i   m   i   l   a   r       t   o          h   t   t   p   -   g   e   t      ,       e   x   c   e   p   t       i   t       u   s   e   s       t   h   e       "   P   O   S   T   "   
   m   e   t   h   o   d   .           S   e   e          h   t   t   p   -   g   e   t          f   o   r       f   u   l   l       d   o   c   u   m   e   n   t   a   t   i   o   n       o   n       t   h   e       v   a   r   i   o   u   s       k   e   y   w   o   r   d   
   a   r   g   u   m   e   n   t   s       t   h   a   t       a   r   e       a   c   c   e   p   t   e   d       b   y       t   h   i   s       f   u   n   c   t   i   o   n   .   
   
   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C7R3    h   ]  - /   0   3 #  #  	4 5#  #  #  #  #   	

6 U      g  uri
		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
streaming?			  g  filenamef  web/client.scm
Y
	eZ		Y
 		
g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
streaming?S	   g  nameg  http-putg  
documentation  k P   u   t       d   a   t   a       a   t       t   h   e       g   i   v   e   n       U   R   I       u   s   i   n   g       t   h   e       H   T   T   P       "   P   U   T   "       m   e   t   h   o   d   .   
   
   T   h   i   s       f   u   n   c   t   i   o   n       i   s       s   i   m   i   l   a   r       t   o          h   t   t   p   -   g   e   t      ,       e   x   c   e   p   t       i   t       u   s   e   s       t   h   e       "   P   U   T   "   
   m   e   t   h   o   d   .           S   e   e          h   t   t   p   -   g   e   t          f   o   r       f   u   l   l       d   o   c   u   m   e   n   t   a   t   i   o   n       o   n       t   h   e       v   a   r   i   o   u   s       k   e   y   w   o   r   d   
   a   r   g   u   m   e   n   t   s       t   h   a   t       a   r   e       a   c   c   e   p   t   e   d       b   y       t   h   i   s       f   u   n   c   t   i   o   n   .   
   
   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C8R3        h     - /   0   3 #  #  	4 5#  #  #  #  #   	

6 }      g  uri
		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
streaming?			  g  filenamef  web/client.scm
c
	ed		c
 		
g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
streaming?S	   g  nameg  http-deleteg  
documentation   k D   e   l   e   t   e       d   a   t   a       a   t       t   h   e       g   i   v   e   n       U   R   I       u   s   i   n   g       t   h   e       H   T   T   P       "   D   E   L   E   T   E   "       m   e   t   h   o   d   .   
   
   T   h   i   s       f   u   n   c   t   i   o   n       i   s       s   i   m   i   l   a   r       t   o          h   t   t   p   -   g   e   t      ,       e   x   c   e   p   t       i   t       u   s   e   s       t   h   e       "   D   E   L   E   T   E   "   
   m   e   t   h   o   d   .           S   e   e          h   t   t   p   -   g   e   t          f   o   r       f   u   l   l       d   o   c   u   m   e   n   t   a   t   i   o   n       o   n       t   h   e       v   a   r   i   o   u   s       k   e   y   w   o   r   d   
   a   r   g   u   m   e   n   t   s       t   h   a   t       a   r   e       a   c   c   e   p   t   e   d       b   y       t   h   i   s       f   u   n   c   t   i   o   n   .   
   
   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C9R3        h     - /   0   3 #  #  	4 5#  #  #  #  #   	

6       g  uri
		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
streaming?			  g  filenamef  web/client.scm
m
	en		m
 		
g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
streaming?S	   g  nameg  
http-traceg  
documentationk dS   e   n   d       a   n       H   T   T   P       "   T   R   A   C   E   "       r   e   q   u   e   s   t   .   
   
   T   h   i   s       f   u   n   c   t   i   o   n       i   s       s   i   m   i   l   a   r       t   o          h   t   t   p   -   g   e   t      ,       e   x   c   e   p   t       i   t       u   s   e   s       t   h   e       "   T   R   A   C   E   "   
   m   e   t   h   o   d   .           S   e   e          h   t   t   p   -   g   e   t          f   o   r       f   u   l   l       d   o   c   u   m   e   n   t   a   t   i   o   n       o   n       t   h   e       v   a   r   i   o   u   s       k   e   y   w   o   r   d   
   a   r   g   u   m   e   n   t   s       t   h   a   t       a   r   e       a   c   c   e   p   t   e   d       b   y       t   h   i   s       f   u   n   c   t   i   o   n   .   
   
   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C:R3    h     - /   0   3 #  #  	4 5#  #  #  #  #   	

6       g  uri
		 g  body		 g  port			 g  version			 g  keep-alive?			 g  headers			 g  decode-body?			 g  
streaming?			  g  filenamef  web/client.scm
w
	ex		w
 		
g  bodySg  portS	g  versionS	g  keep-alive?S	g  headersS	g  decode-body?S	g  
streaming?S	   g  nameg  http-optionsg  
documentation  k  Q   u   e   r   y       c   h   a   r   a   c   t   e   r   i   s   t   i   c   s       o   f       a   n       H   T   T   P       r   e   s   o   u   r   c   e       u   s   i   n   g       t   h   e       H   T   T   P       "   O   P   T   I   O   N   S   "   
   m   e   t   h   o   d   .   
   
   T   h   i   s       f   u   n   c   t   i   o   n       i   s       s   i   m   i   l   a   r       t   o          h   t   t   p   -   g   e   t      ,       e   x   c   e   p   t       i   t       u   s   e   s       t   h   e       "   O   P   T   I   O   N   S   "   
   m   e   t   h   o   d   .           S   e   e          h   t   t   p   -   g   e   t          f   o   r       f   u   l   l       d   o   c   u   m   e   n   t   a   t   i   o   n       o   n       t   h   e       v   a   r   i   o   u   s       k   e   y   w   o   r   d   
   a   r   g   u   m   e   n   t   s       t   h   a   t       a   r   e       a   c   c   e   p   t   e   d       b   y       t   h   i   s       f   u   n   c   t   i   o   n   .   
   
   R   e   t   u   r   n   s       t   w   o       v   a   l   u   e   s   :       t   h   e       r   e   s   u   l   t   i   n   g       r   e   s   p   o   n   s   e   ,       a   n   d       t   h   e       r   e   s   p   o   n   s   e       b   o   d   y   .    C;RC  %      g  m
		, g  proxy
	:	O  g  filenamef  web/client.scm		!
	-	9		2	9		8	9	'	:	9		:	9		@	:	,	A	:		E	:		Q	9		T	8
n	=
	C
	V	j
	s
 K 
% 
= 
@#
LB
S,O
Z8Y
apc
h$m
ow
 	o
   C6 